package org.dbunit;

import org.dbunit.database.IDatabaseConnection;

/**
 * Base testCase for database testing.<br>
 * Subclasses may override {@link newDatabaseTester()} to plug-in a different implementation
 * of IDatabaseTester.<br> Default implementation uses a {@link PropertiesBasedJdbcDatabaseTester}.
 *
 * @author Felipe Leme <dbunit@felipeal.net>
 */
public abstract class DBTestCase extends DatabaseTestCase {

  public DBTestCase() {
    super();
  }

  public DBTestCase(String name) {
    super(name);
  }

  protected IDatabaseConnection getConnection() throws Exception {
    final IDatabaseTester databaseTester = getDatabaseTester();
    assertNotNull( "DatabaseTester is not set", databaseTester );
    return databaseTester.getConnection();
 }

  /**
   * Creates a new IDatabaseTester.
   * Default implementation returns a {@link PropertiesBasedJdbcDatabaseTester}.
   */
  protected IDatabaseTester newDatabaseTester() throws Exception {
    return new PropertiesBasedJdbcDatabaseTester();
  }

}
